==> ToolChain_STM32_1.0.27.tar.bz: ToolChain_STM32/Template/main.c <==
/*{ TemplateName::main.c ********************************************
 
 * Project TemplateName
 * Author: TemplateAuthor

 * Template written 2010-2011 by Gregor Rebel
 
 * Basic framework template for
     - Olimex STM32-P107/ STM32-H107/ STM32-LCD eval board
     - StdPeripheralsLibrary CMSIS V3.4.0 (tested)
     - GNU toolchain from CodeSourcery G++
     - FreeRTOS v7.0.1
     - FixPointLib 
     - uIP TCP/IP-Stack
     - Color LCD Panel 320x240
     - local/ remote debugging (JTAG-Adapter may be connected to different computer)


 * Coding-style
    + gnu99
      It's year 2011, get a decent compiler if your's does not comply with this.
      arm-none-eabi-gcc-4.4.1 does support gnu99.
      
    + Text Folding
      This source makes use of text folding to improve hierarchical readability 
      It has been written with jEdit + plugin Configurable Fold Handler.
      Activate folding in your favourite text-editor for { and } 
      (fold-start and -end) for best visual experience.


 * Compile:
   ./compile.sh  # will automatically download and install complete ToolChain if required

 * Flash onto u-controller:
   - change _openocd_flash.sh according to your board and adapter
   - flash binary
     ./_/openocd_flash.sh main.bin
   
 * Debug:
   - change openocd_gdb.sh and gdb.sh according to your board and adapter
   - start openocd as gdb-server (may even run on another computer connected over network)
     ./_/openocd_gdb.sh
   - start gdb text user-interface in another shell
     ./_/gdb.sh
     
         

 * Configuration of source-code:
    + stm32f10x_conf.h
      - modify according to your hardware (if differing from above) 
    
    + stm32f10x_it.c .
      - implement your own interrupthandlers in existing functions
      
    + main.c (this file)
      - extend as you like
      
    + makefile
      - all .c, .h and .s files in local directory are compiled and linked together automatically.
      - choose microcontroller according to your current device
      - select features to be activated (network, lcd, fixpoint library, ...)
      - add .o file entries for additional .c to be compiled
      
 * Prerequisites:
   - ToolChain_STM32 (http://hlb-labor.de/cortexm3)
     Latest version should be downloaded and installed automatically by issuing ./compile.sh


  * Scripts:
    Some helper scripts can be found inside ./_/
    Each script-name starts with a comma to make it easy to tab them after adding scripts/ to $PATH.
    
    clean.sh           removes all object files in current and all subfolders
    compile.sh         cleans, compiles and flashes application 
    cscope.sh          creates a searchable index of all .c and .h files (jEdit provides cscope-plugin)
    findFile.sh        finds file for given filename or wildcard
    findInSources.sh   searches for given text in all .h files of given folder
    flash.sh           kills running openocd + starts openocd_flash.sh
    gdb.sh             starts remote gdb-session (change according to your setup)
    jedit.sh           wrapper for cscope to use jEdit as Source-Browser (download from jedit.org)
                       Issue before starting cscope: export CSCOPE_EDITOR=`pwd`/scripts/jedit.sh
    openocd_flash.sh   starts openocd to flash given binary onto uC 
    openocd_gdb.sh     starts openocd as GDB server waiting for a GDB to connect
    paths.sh           can be sourced to provide all required paths (adapt to your setting before)
                       Usage: add a line similar to this to your ~/.bashrc
                       source $HOME/Source/STM32_Template/scripts/paths.sh
                       
    Examples:
    ./_/findFile.sh *gpio.h                             # find all files which name ends with gpio.h
    ./_/findInSources.sh StdPeripheralsLibrary/ GPIOC   # find all .h-files which contain keyword GPIOC inside folder
    ./_/findInSources.sh ./ EXTI0_IRQChannel            # find all files (even binaries) containing EXTI_RTR (lengthy!)
    ./_/clean.sh

}*/
//{ Defines/ TypDefs *****************************************************


//} Defines
//{ Includes *************************************************************

/**
 * IO definitions
 *
 * define access restrictions to peripheral registers
 *
 * (Copied from core_cm3.h because its required to include stm32f10x.h which is required t include core_cm3.h!)
 */

// Basic set of helper functions

#include <stdlib.h>
#include "stddef.h"

#include "stm32_io.h"

#ifdef EXTENSION_debug_registers
#include "stm32_registers.h"
#endif

// FreeRTOS
#include "FreeRTOS.h"
#include "task.h"


#define USE_STDPERIPH_DRIVER
#include "stm32f10x.h"
#include "core_cm3.h"      // StdPeripheralsLibrary/CMSIS/CM3/CoreSupport/
#include "stm32f10x_conf.h"

// Timers
#include "stm32f10x_tim.h"

#include "stm32f10x_it.h"
#include "system_stm32f10x.h"
#include "bits.h"

#include <string.h>

#ifdef EXTENSION_adc
#include "stm32f10x_adc.h"
#include "stm32f10x_dma.h"
#include "Libraries/stm32_adc.h"
#endif

#ifdef EXTENSION_example_threading
  #include "example_threading.h"
#endif
#ifdef EXTENSION_example_leds
  #include "example_leds.h"
#endif
#ifdef EXTENSION_lcd_320x240_olimex
  #include "example_lcd_320x240.h"
#endif
#ifdef EXTENSION_ethernet_uip_ste101p
  #include "stm32_eth.h"
  #include "ethernet.h"
#endif
#ifdef EXTENSION_http_server
    #include "httpd.h"
#endif

//} Includes
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

int main(void);

// task which spawns all other tasks + runs main eventloop
void taskMain(void *pvParameters);

// called in case pvPortMalloc() fails
void vApplicationMallocFailedHook(void);

//} Function prototypes
//{ Function definitions *************************************************

void vApplicationMallocFailedHook(void) {
    while (1);
}
        int main(void) {

    SystemInit();
    
    xTaskCreate(taskMain,                          // function to start as thread
                (const signed char*) "taskMain",   // thread name (just for debugging)
                (size_t) 512, // stack size
                (void *) 0,                        // passed as argument to taskControlLed()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
               );
    
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
}
       void taskMain(void *pvParameters) {

#ifdef EXTENSION_example_threading
  threading_start();
#endif

#ifdef EXTENSION_example_leds
    leds_start();
#endif

#ifdef EXTENSION_lcd_320x240_olimex
    lcd_start();
#endif

#ifdef EXTENSION_http_server

#endif

    while (1) mSleep(1000);
}

//} Function definitions

==> ToolChain_STM32_1.0.29.tar.bz: ToolChain_STM32/Template/main.c <==
/*{ TemplateName::main.c ********************************************
 
 * Project TemplateName
 * Author: TemplateAuthor

 * Template written 2010-2011 by Gregor Rebel
 
 * Basic framework template for
     - Olimex STM32-P107/ STM32-H107/ STM32-LCD eval board
     - StdPeripheralsLibrary CMSIS V3.4.0 (tested)
     - GNU toolchain from CodeSourcery G++
     - FreeRTOS v7.0.1
     - FixPointLib 
     - uIP TCP/IP-Stack
     - Color LCD Panel 320x240
     - local/ remote debugging (JTAG-Adapter may be connected to different computer)


 * Coding-style
    + gnu99
      It's year 2011, get a decent compiler if your's does not comply with this.
      arm-none-eabi-gcc-4.4.1 does support gnu99.
      
    + Text Folding
      This source makes use of text folding to improve hierarchical readability 
      It has been written with jEdit + plugin Configurable Fold Handler.
      Activate folding in your favourite text-editor for { and } 
      (fold-start and -end) for best visual experience.


 * Compile:
   ./compile.sh  # will automatically download and install complete ToolChain if required

 * Flash onto u-controller:
   - change _openocd_flash.sh according to your board and adapter
   - flash binary
     ./_/openocd_flash.sh main.bin
   
 * Debug:
   - change openocd_gdb.sh and gdb.sh according to your board and adapter
   - start openocd as gdb-server (may even run on another computer connected over network)
     ./_/openocd_gdb.sh
   - start gdb text user-interface in another shell
     ./_/gdb.sh
     
         

 * Configuration of source-code:
    + stm32f10x_conf.h
      - modify according to your hardware (if differing from above) 
    
    + stm32f10x_it.c .
      - implement your own interrupthandlers in existing functions
      
    + main.c (this file)
      - extend as you like
      
    + makefile
      - all .c, .h and .s files in local directory are compiled and linked together automatically.
      - choose microcontroller according to your current device
      - select features to be activated (network, lcd, fixpoint library, ...)
      - add .o file entries for additional .c to be compiled
      
 * Prerequisites:
   - ToolChain_STM32 (http://hlb-labor.de/cortexm3)
     Latest version should be downloaded and installed automatically by issuing ./compile.sh


  * Scripts:
    Some helper scripts can be found inside ./_/
    Each script-name starts with a comma to make it easy to tab them after adding scripts/ to $PATH.
    
    clean.sh           removes all object files in current and all subfolders
    compile.sh         cleans, compiles and flashes application 
    cscope.sh          creates a searchable index of all .c and .h files (jEdit provides cscope-plugin)
    findFile.sh        finds file for given filename or wildcard
    findInSources.sh   searches for given text in all .h files of given folder
    flash.sh           kills running openocd + starts openocd_flash.sh
    gdb.sh             starts remote gdb-session (change according to your setup)
    jedit.sh           wrapper for cscope to use jEdit as Source-Browser (download from jedit.org)
                       Issue before starting cscope: export CSCOPE_EDITOR=`pwd`/scripts/jedit.sh
    openocd_flash.sh   starts openocd to flash given binary onto uC 
    openocd_gdb.sh     starts openocd as GDB server waiting for a GDB to connect
    paths.sh           can be sourced to provide all required paths (adapt to your setting before)
                       Usage: add a line similar to this to your ~/.bashrc
                       source $HOME/Source/STM32_Template/scripts/paths.sh
                       
    Examples:
    ./_/findFile.sh *gpio.h                             # find all files which name ends with gpio.h
    ./_/findInSources.sh StdPeripheralsLibrary/ GPIOC   # find all .h-files which contain keyword GPIOC inside folder
    ./_/findInSources.sh ./ EXTI0_IRQChannel            # find all files (even binaries) containing EXTI_RTR (lengthy!)
    ./_/clean.sh

}*/
//{ Defines/ TypDefs *****************************************************


//} Defines
//{ Includes *************************************************************

/**
 * IO definitions
 *
 * define access restrictions to peripheral registers
 *
 * (Copied from core_cm3.h because its required to include stm32f10x.h which is required t include core_cm3.h!)
 */

// Basic set of helper functions

#include <stdlib.h>
#include "stddef.h"

#include "stm32_io.h"

#ifdef EXTENSION_debug_registers
#include "stm32_registers.h"
#endif

// FreeRTOS
#include "FreeRTOS.h"
#include "task.h"


#define USE_STDPERIPH_DRIVER
#include "stm32f10x.h"
#include "core_cm3.h"      // StdPeripheralsLibrary/CMSIS/CM3/CoreSupport/
#include "stm32f10x_conf.h"

// Timers
#include "stm32f10x_tim.h"

#include "stm32f10x_it.h"
#include "system_stm32f10x.h"
#include "bits.h"

#include <string.h>

#ifdef EXTENSION_adc
#include "stm32f10x_adc.h"
#include "stm32f10x_dma.h"
#include "Libraries/stm32_adc.h"
#endif

#ifdef EXTENSION_example_threading_queues
  #include "example_threading_queues.h"
#endif
#ifdef EXTENSION_example_threading_semaphores
  #include "example_threading_semaphores.h"
#endif
#ifdef EXTENSION_example_leds
  #include "example_leds.h"
#endif
#ifdef EXTENSION_lcd_320x240_olimex
  #include "example_lcd_320x240.h"
#endif
#ifdef EXTENSION_network_uip_ste101p
  #include "stm32_eth.h"
  #include "ethernet.h"
  #ifdef EXTENSION_http_server
      #include "httpd.h"
  #endif
#endif
#ifdef EXTENSION_network_lwip
#endif

//} Includes
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

int main(void);

// task which spawns all other tasks + runs main eventloop
void taskMain(void *pvParameters);

// called in case pvPortMalloc() fails
void vApplicationMallocFailedHook(void);

//} Function prototypes
//{ Function definitions *************************************************

void vApplicationMallocFailedHook(void) {
    while (1);
}
        int main(void) {

    SystemInit();
    
    xTaskCreate(taskMain,                          // function to start as thread
                (const signed char*) "taskMain",   // thread name (just for debugging)
                (size_t) 512, // stack size
                (void *) 0,                        // passed as argument to taskControlLed()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
               );
    
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
}
       void taskMain(void *pvParameters) {

#ifdef EXTENSION_example_threading_queues
    threading_start();
#endif
#ifdef EXTENSION_example_threading_semaphores
    threading_start();  
#endif
#ifdef EXTENSION_example_leds
    leds_start();
#endif

#ifdef EXTENSION_example_lcd
    lcd_start();
#endif

#ifdef EXTENSION_http_server

#endif

    while (1) mSleep(1000);
}

//} Function definitions
